@@ -68,7 +68,7 @@ def main_run():
             # TODO (vedant) : should parent directories be created recursively too?
             raise FileNotFoundError(f"Parent directory {output_path.parent()} for provided output path: {sys.argv[2]} does not exist. Please recheck that the provided parent path is correct")
         else:
-            os.makedir(sys.argv[2])
+            os.mkdir(sys.argv[2])
 
     # Perform a preliminary error check to ensure number of arguments and directories supplied are correct
     prerun_error_check()
